"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Manager = void 0;
var _clientDynamodb = require("@webiny/aws-sdk/client-dynamodb");
var _apiElasticsearch = require("@webiny/api-elasticsearch");
var _definitions = require("../definitions");
var _entry = require("../definitions/entry");
var _dbDynamodb = require("@webiny/db-dynamodb");
class Manager {
  entities = {};
  constructor(params) {
    this.context = params.context;
    this.documentClient = params?.documentClient || (0, _clientDynamodb.getDocumentClient)();
    this.elasticsearch = params?.elasticsearchClient || params.context.elasticsearch || (0, _apiElasticsearch.createElasticsearchClient)({
      endpoint: `https://${process.env.ELASTIC_SEARCH_ENDPOINT}`
    });
    this.table = (0, _definitions.createTable)({
      documentClient: this.documentClient
    });
    this.isCloseToTimeout = () => {
      return params.isCloseToTimeout();
    };
    this.isAborted = () => {
      return params.isAborted();
    };
    this.response = params.response;
    this.store = params.store;
  }
  getEntity(name) {
    if (this.entities[name]) {
      return this.entities[name];
    }
    return this.entities[name] = (0, _entry.createEntry)({
      table: this.table,
      entityName: name
    });
  }
  async read(items) {
    return await (0, _dbDynamodb.batchReadAll)({
      table: this.table,
      items
    });
  }
  async write(items) {
    return await (0, _dbDynamodb.batchWriteAll)({
      table: this.table,
      items
    });
  }
}
exports.Manager = Manager;

//# sourceMappingURL=Manager.js.map